"""This module provides utilities for streaming lambda results."""

__author__ = "Bartosz Walkowicz"
__copyright__ = "Copyright (C) 2022 ACK CYFRONET AGH"
__license__ = "This software is released under the MIT license cited in LICENSE.txt"


import json
from contextlib import nullcontext
from threading import Lock
from typing import Generic, Iterable, TypeVar

T = TypeVar("T")


class AtmResultStreamer(Generic[T]):
    def __init__(self, *, result_name: str, synchronized: bool) -> None:
        """Inits AtmResultStreamer.

        Args:
            result_name:
                The name of result.
            synchronized:
                The flag telling whether streaming should be thread-safe or not.
        """
        self.result_name = result_name
        self._synchronized_context = Lock() if synchronized else nullcontext()

        super().__init__()

    def stream_item(self, item: T) -> None:
        self.stream_items([item])

    def stream_items(self, items: Iterable[T]) -> None:
        with self._synchronized_context, open(f"/out/{self.result_name}", "a") as f:
            for item in items:
                json.dump(item, f)
                f.write("\n")



#!/usr/bin/env python

from setuptools import setup

from codecs import open
from os import path

HERE = path.abspath(path.dirname(__file__))

with open(path.join(HERE, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="onedata_lambda_utils",
    version="0.1.2",
    python_requires=">=3.7",
    description="Python Library containing utility functions for use in OpenFaaS lambda implementations",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Rafal Widziszewski",
    license="MIT",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Operating System :: OS Independent"
    ],
    packages=["onedata_lambda_utils"],
    package_data={"onedata_lambda_utils": ["py.typed"]},
    include_package_data=True,
    install_requires=["typing-extensions==4.3.0"]
)
